@@ -1,5 +1,5 @@
 package Net::Kubernetes::Namespace;
-$Net::Kubernetes::Namespace::VERSION = '0.04.1';
+$Net::Kubernetes::Namespace::VERSION = '0.01';
 use Moose;
 use MooseX::Aliases;
 
@@ -9,7 +9,7 @@ Net::Kubernetes::Namespace
 
 =head1 VERSION
 
-version 0.04.1
+version 0.01
 
 =cut
 
@@ -23,7 +23,7 @@ has namespace => (
 has _namespace_data => (
 	is       => 'ro',
 	isa      => 'HashRef',
-	required => 0,
+	required => 0,	
 );
 
 with 'Net::Kubernetes::Role::APIAccess';
@@ -56,7 +56,10 @@ alias get_rc => 'get_replication_controller';
 sub get_resource_by_name {
 	my($self, $name, $type) = @_;
 	my($res) = $self->ua->request($self->create_request(GET => $self->url.'/'.$self->base_path.'/'.$type.'/'.$name));
+	print Dumper($res)."\n";
 	if ($res->is_success) {
+		use Data::Dumper;
+		print Dumper($self->json->decode($res->content))."\n";
 		return $self->create_resource_object($self->json->decode($res->content));
 	}
 	else {
