@@ -1,5 +1,5 @@
 package Net::Kubernetes::Resource;
-$Net::Kubernetes::Resource::VERSION = '0.04.1';
+$Net::Kubernetes::Resource::VERSION = '0.01';
 use Moose;
 
 =head1 NAME
@@ -8,7 +8,7 @@ Net::Kubernetes::Resource
 
 =head1 VERSION
 
-version 0.04.1
+version 0.01
 
 =cut
 
@@ -36,22 +36,8 @@ has metadata => (
 sub delete {
 	my($self) = @_;
 	my($res) = $self->ua->request($self->create_request(DELETE => $self->url.'/'.$self->base_path));
-	if ($res->is_success) {
-		return 1;
-	}
-	return 0;
-}
-
-sub update {
-	my($self) = @_;
-	my($res) = $self->ua->request($self->create_request(PUT => $self->url.'/'.$self->base_path, undef, $self->json->encode({spec=>$self->spec, apiVersion=>$self->api_version, kind=>$self->kind, metadata=>$self->metadata})));
-	if ($res->is_success) {
-		return 1;
-	}
 	use Data::Dumper;
 	print Dumper($res)."\n";
-	return 0;
 }
 
-
 return 42;
