@@ -1,5 +1,5 @@
 package Net::Kubernetes::Role::APIAccess;
-$Net::Kubernetes::Role::APIAccess::VERSION = '0.04.1';
+$Net::Kubernetes::Role::APIAccess::VERSION = '0.01';
 use Moose::Role;
 require LWP::UserAgent;
 require HTTP::Request;
@@ -13,7 +13,7 @@ Net::Kubernetes::Role::APIAccess
 
 =head1 VERSION
 
-version 0.04.1
+version 0.01
 
 =cut
 
@@ -29,7 +29,7 @@ has base_path => (
 	is       => 'ro',
 	isa      => 'Str',
 	required => 1,
-	default  => '/api/v1beta3',
+	default  => 'api/v1beta3',
 );
 
 has password => (
@@ -51,12 +51,6 @@ has ua => (
 	builder  => '_build_lwp_agent',
 );
 
-has token => (
-	is       => 'ro',
-	isa      => 'Str',
-	required => 0
-);
-
 has 'json' => (
     is       => 'ro',
     isa      => 'JSON',
@@ -65,31 +59,12 @@ has 'json' => (
     builder  => '_build_json',
 );
 
-around BUILDARGS => sub {
-	my $orig = shift;
-	my $class = shift;
-	my(%input) = @_;
-	if(ref($input{token})){
-		if($input{token}->can('getlines')){
-			$input{token} = join('', $input{token}->getlines);
-		}
-		elsif (ref($input{token}) eq 'GLOB') {
-			my $fh = $input{token};
-			$input{token} = do{ local $/; <$fh>};
-		}
-	}elsif (exists $input{token} && -f $input{token}) {
-		open(my $fh, '<', $input{token});
-		$input{token} = do{ local $/; <$fh>};
-		close($fh);
-	}
-	return $class->$orig(%input);
-};
-
 sub path {
 	my($self) = @_;
-	return $self->url.$self->base_path;
+	return $self->url.'/'.$self->base_path;
 }
 
+
 sub _build_lwp_agent {
 	my $self = shift;
 	my $ua = LWP::UserAgent->new(agent=>'net-kubernetes-perl/0.01');
@@ -107,9 +82,6 @@ sub create_request {
 	if ($self->username && $self->password) {
 		$req->header(Authorization=>"Basic ".encode_base64($self->username.':'.$self->password));
 	}
-	elsif($self->token){
-		$req->header(Authorization=>"Bearer ".$self->token);
-	}
 	return $req;
 }
 
