@@ -1,5 +1,5 @@
 package Net::Kubernetes::Role::ResourceCreator;
-$Net::Kubernetes::Role::ResourceCreator::VERSION = '0.04.1';
+$Net::Kubernetes::Role::ResourceCreator::VERSION = '0.01';
 use Moose::Role;
 use MooseX::Aliases;
 require YAML;
@@ -17,12 +17,10 @@ Net::Kubernetes::Role::ResoruceCreator
 
 =head1 VERSION
 
-version 0.04.1
+version 0.01
 
 =cut
 
-with 'Net::Kubernetes::Role::ResourceFactory';
-
 requires 'ua';
 requires 'create_request';
 requires 'json';
@@ -39,7 +37,7 @@ sub create_from_file {
 		$object = YAML::LoadFile($file);
 	}
 	else{
-		$object = $self->json->decode(scalar(read_file($file)));
+		$object = $self->json->decode(read_file($file));
 	}
 	
 	return $self->create($object);
@@ -50,10 +48,11 @@ sub create {
 	my $req = $self->create_request(POST=>$self->path.'/'.lc($object->{kind}).'s', undef, $self->json->encode($object));
 	my $res = $self->ua->request($req);
 	if ($res->is_success) {
-		return $self->create_resource_object($self->json->decode($res->content));
+		return "Net::Kubernetes::Resource::$object->{kind}"->new($self->json->decode($res->content));
 	}else{
 		Net::Kubernetes::Exception->throw(code=>$res->code, message=>"Error creating resource:\n".$res->message);
 	}
+	
 }
 
 
